@@ -4,10 +4,13 @@ from __future__ import absolute_import, print_function
 #imports
 
 from .neat_goldstandard import NEATDynamic
+from .neat_silverstandard import NEATCynamic
+from .neat_diamondstandard import NEATEynamic
 from .neat_focus import NEATFocus
 from .neat_faststandard import NEATSynamic
-
+from .viz_neat_diamondstandard import VizNEATEynamic
 from .neat_standard import NEATSDynamic
+from .neat_lstmstandard import NEATLDynamic
 from .neat_microscope import NEATPredict
 from .neat_static_standard import NEATStatic
 from .nets import Concat
