@@ -1,38 +1,25 @@
 from oneat.NEATUtils import plotters
 import numpy as np
-from oneat.NEATUtils import helpers
-from oneat.NEATUtils.helpers import  load_json, normalizeFloatZeroOne, focyoloprediction, simpleaveragenms
+from oneat.NEATUtils import utils
+from oneat.NEATUtils.utils import  load_json, normalizeFloatZeroOne, focyoloprediction, simpleaveragenms
 from keras import callbacks
 import os
-import math
 import pandas as pd
-from scipy.ndimage.filters import median_filter, gaussian_filter, maximum_filter
 import tensorflow as tf
 from tqdm import tqdm
 from oneat.NEATModels import nets
 from oneat.NEATModels.nets import Concat
 from oneat.NEATModels.loss import dynamic_yolo_loss
 from keras import backend as K
-#from IPython.display import clear_output
+import tensorflow as tf
 from keras import optimizers
 from pathlib import Path
 from keras.models import load_model
 from tifffile import imread, imwrite
 import csv
 from scipy.optimize import curve_fit
-import napari
-import glob
-import itertools
-#from napari.qt.threading import thread_worker
 import matplotlib.pyplot  as plt
-#from matplotlib.backends.backend_qt5agg import \
-    #FigureCanvasQTAgg as FigureCanvas
-from matplotlib.figure import Figure
-#from qtpy.QtCore import Qt
-#from qtpy.QtWidgets import QComboBox, QPushButton, QSlider
 import h5py
-#import cv2
-import imageio
 Boxname = 'ImageIDBox'
 EventBoxname = 'EventIDBox'
 
@@ -181,9 +168,9 @@ class NEATFocus(object):
         
     def loadData(self):
         
-        (X,Y),  axes = helpers.load_full_training_data(self.npz_directory, self.npz_name, verbose= True)
+        (X,Y),  axes = utils.load_full_training_data(self.npz_directory, self.npz_name, verbose= True)
 
-        (X_val,Y_val), axes = helpers.load_full_training_data(self.npz_directory, self.npz_val_name,  verbose= True)
+        (X_val,Y_val), axes = utils.load_full_training_data(self.npz_directory, self.npz_val_name,  verbose= True)
         
         
         self.Xoriginal = X
@@ -495,18 +482,9 @@ class NEATFocus(object):
 
 
     def draw(self):
-          colors = [(0,255,0),(0,0,255),(255,0,0)]
-          # fontScale
-          fontScale = 1
-
-          # Blue color in BGR
-          textcolor = (255, 0, 0)
-
-          # Line thickness of 2 px
-          thickness = 2  
+         
           for (event_name,event_label) in self.key_categories.items():
                    
-                  event_maskboxes = []
                   if event_label > 0:
                                   
                                    xlocations = []
@@ -562,34 +540,7 @@ class NEATFocus(object):
                                    
                         
                                         
-                                   for j in range(len(xlocations)):
-                                     startlocation = (int(xlocations[j] - heights[j]//2), int(ylocations[j]-widths[j]//2))
-                                     endlocation =  (int(xlocations[j] + heights[j]//2), int(ylocations[j]+ widths[j]//2))
-                                     Z = int(zlocations[j])  
-                                     
-                                   
-                                     
-                                     
-                                     if event_label == 1:                            
-                                       image = self.Colorimage[Z,:,:,1]
-
-                                       color = (0,255,0)
-                                     else:
-                                       color = (0,0,255)
-                                       image = self.Colorimage[Z,:,:,2]
-
-                                     img = cv2.cvtColor(image, cv2.COLOR_BGR2RGB)
-
-                                     cv2.rectangle(img, startlocation, endlocation, textcolor, thickness)
-                                    
-    
-                                     cv2.putText(img, str('%.4f'%(scores[j])), startlocation, cv2.FONT_HERSHEY_SIMPLEX, 1, textcolor,thickness, cv2.LINE_AA)
-                                     if event_label == 1:
-                                       self.Colorimage[Z,:,:,1] = img[:,:,0]
-                                     else:
-                                       self.Colorimage[Z,:,:,2] = img[:,:,0]
-                                    
-
+                                 
 
                   
 
@@ -597,79 +548,7 @@ class NEATFocus(object):
     
     
     
-    
-    def showNapari(self, imagedir, savedir, yolo_v2 = False):
-         
-         
-         Raw_path = os.path.join(imagedir, '*tif')
-         X = glob.glob(Raw_path)
-         self.savedir = savedir
-         Imageids = []
-         self.viewer = napari.Viewer()
-         napari.run()
-         for imagename in X:
-             Imageids.append(imagename)
-         
-         
-         eventidbox = QComboBox()
-         eventidbox.addItem(EventBoxname)
-         for (event_name,event_label) in self.key_categories.items():
-             
-             eventidbox.addItem(event_name)
-            
-         imageidbox = QComboBox()   
-         imageidbox.addItem(Boxname)   
-         detectionsavebutton = QPushButton(' Save detection Movie')
-         
-         for i in range(0, len(Imageids)):
-             
-             
-             imageidbox.addItem(str(Imageids[i]))
-             
-             
-         figure = plt.figure(figsize=(4, 4))
-         multiplot_widget = FigureCanvas(figure)
-         ax = multiplot_widget.figure.subplots(1, 1)
-         width = 400
-         dock_widget = self.viewer.window.add_dock_widget(
-         multiplot_widget, name="EventStats", area='right')
-         multiplot_widget.figure.tight_layout()
-         self.viewer.window._qt_window.resizeDocks([dock_widget], [width], Qt.Horizontal)    
-         eventidbox.currentIndexChanged.connect(lambda eventid = eventidbox : EventViewer(
-                 self.viewer,
-                 imread(imageidbox.currentText()),
-                 eventidbox.currentText(),
-                 self.key_categories,
-                 os.path.basename(os.path.splitext(imageidbox.currentText())[0]),
-                 savedir,
-                 multiplot_widget,
-                 ax,
-                 figure,
-                 yolo_v2,
-            
-        )
-    )    
-         
-         imageidbox.currentIndexChanged.connect(
-         lambda trackid = imageidbox: EventViewer(
-                 self.viewer,
-                 imread(imageidbox.currentText()),
-                 eventidbox.currentText(),
-                 self.key_categories,
-                 os.path.basename(os.path.splitext(imageidbox.currentText())[0]),
-                 savedir,
-                 multiplot_widget,
-                 ax,
-                 figure,
-                 yolo_v2,
-            
-        )
-    )            
-         
-         
-         self.viewer.window.add_dock_widget(eventidbox, name="Event", area='left')  
-         self.viewer.window.add_dock_widget(imageidbox, name="Image", area='left')     
-                                      
+   
                                                              
                              
     def overlaptiles(self, sliceregion):
@@ -845,92 +724,6 @@ def CreateVolume(patch, imagez, timepoint, imagey, imagex):
                smallimg = patch[starttime:endtime, :]
        
                return smallimg         
-class EventViewer(object):
-    
-    def __init__(self, viewer, image, event_name, key_categories, imagename, savedir, canvas, ax, figure, yolo_v2):
-        
-        
-           self.viewer = viewer
-           self.image = image
-           self.event_name = event_name
-           self.imagename = imagename
-           self.canvas = canvas
-           self.key_categories = key_categories
-           self.savedir = savedir
-           self.ax = ax
-           self.yolo_v2 = yolo_v2
-           self.figure = figure
-           self.plot()
-    
-    def plot(self):
-        
-        self.ax.cla()
-        
-        for (event_name,event_label) in self.key_categories.items():
-                        if event_label > 0 and self.event_name == event_name:
-                             csvname = self.savedir + "/" + event_name + "Location" + (os.path.splitext(os.path.basename(self.imagename))[0] + '.csv')
-                             event_locations, size_locations, angle_locations, line_locations, timelist, eventlist = self.event_counter(csvname)
-                             
-                             for layer in list(self.viewer.layers):
-                                     if event_name in layer.name or layer.name in event_name or event_name + 'angle' in layer.name or layer.name in event_name + 'angle' :
-                                            self.viewer.layers.remove(layer)
-                                     if 'Image' in layer.name or layer.name in 'Image':
-                                            self.viewer.layers.remove(layer)  
-                             self.viewer.add_image(self.image, name='Image')               
-                             self.viewer.add_points(np.asarray(event_locations), size = size_locations ,name = event_name, face_color = [0]*4, edge_color = "red", edge_width = 1)
-                             if self.yolo_v2:
-                                self.viewer.add_shapes(np.asarray(line_locations), name = event_name + 'angle',shape_type='line', face_color = [0]*4, edge_color = "red", edge_width = 1)
-                             self.viewer.theme = 'light'
-                             self.ax.plot(timelist, eventlist, '-r')
-                             self.ax.set_title(event_name + "Events")
-                             self.ax.set_xlabel("Time")
-                             self.ax.set_ylabel("Counts")
-                             self.figure.canvas.draw()
-                             self.figure.canvas.flush_events()
-                             plt.savefig(self.savedir  + event_name   + '.png') 
-                             
-    def event_counter(self, csv_file):
-     
-         time,y,x,score,size,confidence,angle  = np.loadtxt(csv_file, delimiter = ',', skiprows = 1, unpack=True)
-         
-         radius = 10
-         eventcounter = 0
-         eventlist = []
-         timelist = []   
-         listtime = time.tolist()
-         listy = y.tolist()
-         listx = x.tolist()
-         listsize = size.tolist()
-         listangle = angle.tolist()
-         
-         event_locations = []
-         size_locations = []
-         angle_locations = []
-         line_locations = []
-         for i in range(len(listtime)):
-             tcenter = int(listtime[i])
-             print(tcenter)
-             ycenter = listy[i]
-             xcenter = listx[i]
-             size = listsize[i]
-             angle = listangle[i]
-             eventcounter = listtime.count(tcenter)
-             timelist.append(tcenter)
-             eventlist.append(eventcounter)
-             
-             event_locations.append([tcenter, ycenter, xcenter])   
-             size_locations.append(size)
-             
-             xstart = xcenter + radius * math.cos(angle )
-             xend = xcenter - radius  * math.cos(angle)
-             
-             ystart = ycenter + radius * math.sin(angle)
-             yend = ycenter - radius * math.sin(angle)
-             line_locations.append([[tcenter, ystart, xstart], [tcenter, yend, xend]])
-             angle_locations.append(angle)
-             
-            
-         return event_locations, size_locations, angle_locations, line_locations, timelist, eventlist
 
 
 def normalizeZeroOne(x):
