@@ -1,35 +1,21 @@
 from oneat.NEATUtils import plotters
 import numpy as np
-from oneat.NEATUtils import helpers
-from oneat.NEATUtils.helpers import MidSlices,  MidSlicesSum, get_nearest,  load_json, yoloprediction, normalizeFloatZeroOne, GenerateMarkers, MakeTrees, DownsampleData,save_dynamic_csv, dynamic_nms, gold_nms
+from oneat.NEATUtils import utils
+from oneat.NEATUtils.utils import pad_timelapse,  MidSlicesSum, get_nearest,  load_json, yoloprediction, normalizeFloatZeroOne, GenerateMarkers, MakeTrees, DownsampleData,save_dynamic_csv, dynamic_nms, gold_nms
 from keras import callbacks
 import os
-import keras
 import sys
-from scipy.ndimage.morphology import binary_dilation, binary_erosion
-import math
 from tqdm import tqdm
 from oneat.NEATModels import nets
 from oneat.NEATModels.nets import Concat
 from oneat.NEATModels.loss import dynamic_yolo_loss
-from keras import backend as K
 import tensorflow as tf
 from oneat.pretrained import get_registered_models, get_model_details, get_model_instance
 from pathlib import Path
 from keras.models import load_model
+from tensorflow.keras.utils import plot_model
 from tifffile import imread, imwrite
-import napari
-import glob
-from skimage.morphology import erosion, dilation, disk
-import matplotlib.pyplot as plt
-from matplotlib.backends.backend_qt5agg import \
-    FigureCanvasQTAgg as FigureCanvas
-from qtpy.QtCore import Qt
-from qtpy.QtWidgets import QComboBox, QPushButton
-import cv2
-from scipy import ndimage
-from skimage.measure import label
-from skimage import measure
+
 Boxname = 'ImageIDBox'
 EventBoxname = 'EventIDBox'
 
@@ -67,13 +53,14 @@ class NEATDynamic(object):
     
     """
 
-    def __init__(self, config, model_dir, model_name,  catconfig=None, cordconfig=None):
+    def __init__(self, config, model_dir, model_name,  catconfig=None, cordconfig=None, pure_lstm = False):
 
         self.config = config
         self.catconfig = catconfig
         self.cordconfig = cordconfig
         self.model_dir = model_dir
         self.model_name = model_name
+        self.pure_lstm = pure_lstm
         if self.config != None:
             self.npz_directory = config.npz_directory
             self.npz_name = config.npz_name
@@ -149,7 +136,6 @@ class NEATDynamic(object):
             self.yolo_v1 = self.config['yolo_v1']
             self.yolo_v2 = self.config['yolo_v2']
             self.stride = self.config['stride']
-            self.lstm_hidden_unit = self.config['lstm_hidden_unit']
 
         self.X = None
         self.Y = None
@@ -160,10 +146,11 @@ class NEATDynamic(object):
         self.Xoriginal = None
         self.Xoriginal_val = None
 
-        if self.residual:
-            self.model_keras = nets.ORNET
-        else:
-            self.model_keras = nets.OSNET
+        if self.pure_lstm == False:  
+           self.model_keras = nets.ORNET
+        if self.pure_lstm:
+            self.model_keras = nets.LORNET   
+      
 
         if self.multievent == True:
             self.last_activation = 'sigmoid'
@@ -189,9 +176,9 @@ class NEATDynamic(object):
 
     def loadData(self):
 
-        (X, Y), axes = helpers.load_full_training_data(self.npz_directory, self.npz_name, verbose=True)
+        (X, Y), axes = utils.load_full_training_data(self.npz_directory, self.npz_name, verbose=True)
 
-        (X_val, Y_val), axes = helpers.load_full_training_data(self.npz_directory, self.npz_val_name, verbose=True)
+        (X_val, Y_val), axes = utils.load_full_training_data(self.npz_directory, self.npz_val_name, verbose=True)
 
         self.Xoriginal = X
         self.Xoriginal_val = X_val
@@ -265,7 +252,9 @@ class NEATDynamic(object):
         sgd = tf.keras.optimizers.Adam(learning_rate=self.learning_rate)
         self.Trainingmodel.compile(optimizer=sgd, loss=self.yololoss, metrics=['accuracy'])
         self.Trainingmodel.summary()
-
+        plot_model(self.Trainingmodel, to_file = self.model_dir + self.model_name +'.png', 
+        show_shapes = True, show_layer_names=True)
+   
         # Keras callbacks
         lrate = callbacks.ReduceLROnPlateau(monitor='loss', factor=0.1, patience=4, verbose=1)
         hrate = callbacks.History()
@@ -286,32 +275,33 @@ class NEATDynamic(object):
         self.Trainingmodel.save(os.path.join(self.model_dir, self.model_name) )
 
     def get_markers(self, imagename, segdir, start_project_mid = 4, end_project_mid = 4,
-     downsamplefactor = 1):
+     downsamplefactor = 1, dtype = 'uint16'):
 
         self.imagename = imagename
         self.segdir = segdir
         Name = os.path.basename(os.path.splitext(self.imagename)[0])
-      
+        self.pad_width = (self.config['imagey'], self.config['imagex'])
         self.downsamplefactor = downsamplefactor
         print('Obtaining Markers')
-        self.segimage = imread(self.segdir + '/' + Name + '.tif')
+        self.segimage = imread(self.segdir + '/' + Name + '.tif').astype(dtype)
         self.markers = GenerateMarkers(self.segimage, 
-        start_project_mid = start_project_mid, end_project_mid = end_project_mid)
+        start_project_mid = start_project_mid, end_project_mid = end_project_mid, pad_width = self.pad_width)
         self.marker_tree = MakeTrees(self.markers)
         self.segimage = None         
 
         return self.marker_tree
     
-    def predict(self, imagename,  savedir, n_tiles=(1, 1), overlap_percent=0.8,
+    def predict(self, imagename,  savedir, n_tiles=(1, 1), overlap_percent=0.8, dtype = np.uint8,
                 event_threshold=0.5, event_confidence = 0.5, iou_threshold=0.1,  fidelity=1, downsamplefactor = 1, start_project_mid = 4, end_project_mid = 4,
-                erosion_iterations = 1,  marker_tree = None, remove_markers = False, normalize = True, center_oneat = True, nms_function = 'iou'):
+                marker_tree = None, remove_markers = False, normalize = True, center_oneat = True, nms_function = 'iou'):
 
 
         
         self.imagename = imagename
+        self.dtype = dtype
         self.Name = os.path.basename(os.path.splitext(self.imagename)[0])
         self.nms_function = nms_function 
-        self.image = imread(imagename)
+        self.image = imread(imagename).astype(self.dtype)
         self.start_project_mid = start_project_mid
         self.end_project_mid = end_project_mid
         self.ndim = len(self.image.shape)
@@ -322,12 +312,9 @@ class NEATDynamic(object):
            print(f'Image {self.image.shape} is {self.ndim} dimensional, projecting around the center {self.image.shape[1]//2} - {self.start_project_mid} to {self.image.shape[1]//2} + {self.end_project_mid}') 
            self.image =  MidSlicesSum(self.image, self.start_project_mid, self.end_project_mid, axis = 1)
            self.z = self.z - (self.start_project_mid + self.end_project_mid)//2
-        if self.normalize: 
-                    self.image = normalizeFloatZeroOne(self.image.astype('float32'), 1, 99.8)
-        self.erosion_iterations = erosion_iterations
+      
         
-        self.heatmap = np.zeros(self.image.shape, dtype = 'float32')  
-        self.eventmarkers = np.zeros(self.image.shape, dtype = 'uint16')
+        self.heatmap = np.zeros(self.image.shape, dtype = 'uint16')  
         self.savedir = savedir
         Path(self.savedir).mkdir(exist_ok=True)
         if len(n_tiles) > 2:
@@ -341,7 +328,6 @@ class NEATDynamic(object):
         self.downsamplefactor = downsamplefactor
         self.originalimage = self.image
         self.center_oneat = center_oneat
-
         
         self.model = load_model(os.path.join(self.model_dir, self.model_name) + '.h5',
                                 custom_objects={'loss': self.yololoss, 'Concat': Concat})
@@ -350,19 +336,28 @@ class NEATDynamic(object):
         self.remove_markers = remove_markers
         if self.remove_markers:
              self.image = DownsampleData(self.image, self.downsamplefactor)
-
-        
+        if self.normalize: 
+            self.image = normalizeFloatZeroOne(self.image, 1, 99.8, dtype = self.dtype)
         if self.remove_markers == True:
            self.generate_maps = False 
+
+           self.image = pad_timelapse(self.image, self.pad_width)
+           print(f'zero padded image shape ${self.image.shape}')
            self.first_pass_predict()
            self.second_pass_predict()
         if self.remove_markers == False:
-           self.generate_maps = False   
+           self.generate_maps = False 
+
+           self.image = pad_timelapse(self.image, self.pad_width)
+           print(f'zero padded image shape ${self.image.shape}')
            self.second_pass_predict()
         if self.remove_markers == None:
            self.generate_maps = True 
            self.default_pass_predict() 
 
+        
+
+
     def default_pass_predict(self):
         eventboxes = []
         classedboxes = {}    
@@ -372,15 +367,13 @@ class NEATDynamic(object):
         print('Detecting event locations')
         self.image = DownsampleData(self.image, self.downsamplefactor)
         for inputtime in tqdm(range(0, self.image.shape[0])):
-                    if inputtime < self.image.shape[0] - self.imaget:
+                    if inputtime < self.image.shape[0] - self.imaget and inputtime > int(self.imaget)//2:
                                 count = count + 1
                                 if inputtime%(self.image.shape[0]//4)==0 and inputtime > 0 or inputtime >= self.image.shape[0] - self.imaget - 1:
                                       
-                                                                              
-                                      
                                       imwrite((heatsavename + '.tif' ), self.heatmap)
                                       
-                                smallimage = CreateVolume(self.image, self.imaget, inputtime)
+                                smallimage = CreateVolume(self.image, self.size_tminus, self.size_tplus, inputtime)
                                 
                                 # Cut off the region for training movie creation
                                 #Break image into tiles if neccessary
@@ -393,10 +386,11 @@ class NEATDynamic(object):
                                      #For each tile the prediction vector has shape N H W Categories + Training Vector labels
                                      for i in range(0, sum_time_prediction.shape[0]):
                                           time_prediction =  sum_time_prediction[i]
-                                          boxprediction = yoloprediction(ally[p], 
+                                          boxprediction = yoloprediction(
+                                          ally[p], 
                                           allx[p], 
                                           time_prediction, 
-                                          self.stride, inputtime , 
+                                          self.stride, inputtime -  int(self.imaget)//2, 
                                           self.config, 
                                           self.key_categories, 
                                           self.key_cord, 
@@ -440,11 +434,11 @@ class NEATDynamic(object):
         
         
         for inputtime in tqdm(range(0, self.image.shape[0])):
-            if inputtime < self.image.shape[0] - self.imaget:
+            if inputtime < self.image.shape[0] - self.imaget and inputtime > int(self.imaget)//2:
                 
                 remove_candidates_list = []
-                smallimage = CreateVolume(self.image, self.imaget, inputtime)
-               
+                smallimage = CreateVolume(self.image, self.size_tminus, self.size_tplus, inputtime)
+
                 # Cut off the region for training movie creation
                 # Break image into tiles if neccessary
                 predictions, allx, ally = self.predict_main(smallimage)
@@ -458,7 +452,7 @@ class NEATDynamic(object):
                         for i in range(0, sum_time_prediction.shape[0]):
                             time_prediction = sum_time_prediction[i]
                             boxprediction = yoloprediction(ally[p], allx[p], time_prediction, self.stride,
-                                                           inputtime, self.config,
+                                                           inputtime - int(self.imaget)//2, self.config,
                                                            self.key_categories, self.key_cord, self.nboxes, 'detection',
                                                            'dynamic', marker_tree = self.marker_tree, center_oneat = False)
                                           
@@ -471,8 +465,7 @@ class NEATDynamic(object):
                                 for box in eventboxes:
                 
                                     event_prob = box[event_name]
-                                    event_confidence = box['confidence']
-                                    if event_prob >= self.event_threshold and event_confidence >= self.event_confidence :
+                                    if event_prob >= 0.5 :
 
                                         current_event_box.append(box)
                                         classedboxes[event_name] = [current_event_box]
@@ -515,55 +508,54 @@ class NEATDynamic(object):
         self.n_tiles = (1,1)
         
         heatsavename = self.savedir+ "/"  + (os.path.splitext(os.path.basename(self.imagename))[0])+ '_Heat'
-        eventsavename = self.savedir + "/" + (os.path.splitext(os.path.basename(self.imagename))[0])+ '_Event'
         
   
         for inputtime in tqdm(range(int(self.imaget)//2, self.image.shape[0])):
              if inputtime < self.image.shape[0] - self.imaget:   
+                smallimage = CreateVolume(self.image, self.size_tminus, self.size_tplus, inputtime)
 
                 if inputtime%(self.image.shape[0]//4)==0 and inputtime > 0 or inputtime >= self.image.shape[0] - self.imaget - 1:
-                                      markers_current = dilation(self.eventmarkers[inputtime,:], disk(2))
-                                      self.eventmarkers[inputtime,:] = label(markers_current.astype('uint16')) 
                                       imwrite((heatsavename + '.tif' ), self.heatmap) 
-                                      imwrite((eventsavename + '.tif' ), self.eventmarkers.astype('uint16'))
-                tree, location = self.marker_tree[str(int(inputtime))]
-                for i in range(len(location)):
-                    
-                    crop_xminus = location[i][1]  - int(self.imagex/2) * self.downsamplefactor 
-                    crop_xplus = location[i][1]  + int(self.imagex/2) * self.downsamplefactor 
-                    crop_yminus = location[i][0]  - int(self.imagey/2) * self.downsamplefactor 
-                    crop_yplus = location[i][0]   + int(self.imagey/2) * self.downsamplefactor 
-                    region =(slice(inputtime - int(self.imaget)//2,inputtime + int(self.imaget)//2 + 1),slice(int(crop_yminus), int(crop_yplus)),
-                          slice(int(crop_xminus), int(crop_xplus)))
-                    
-                    crop_image = self.image[region] 
-                    
-                    if crop_image.shape[0] >= self.imaget and  crop_image.shape[1] >= self.imagey * self.downsamplefactor and crop_image.shape[2] >= self.imagex * self.downsamplefactor:                                                
-                                #Now apply the prediction for counting real events
-                               
-                                crop_image = DownsampleData(crop_image, self.downsamplefactor)
-                                ycenter = location[i][0]
-                                xcenter = location[i][1]
-                                  
-                                predictions, allx, ally = self.predict_main(crop_image)
-                                sum_time_prediction = predictions[0]
-                                if sum_time_prediction is not None:
-                                     #For each tile the prediction vector has shape N H W Categories + Training Vector labels
-                                     time_prediction =  sum_time_prediction[0]
-                                     boxprediction = yoloprediction(0, 0 , time_prediction, self.stride,
-                                                           inputtime, self.config,
-                                                           self.key_categories, self.key_cord, self.nboxes, 'detection',
-                                                           'dynamic', center_oneat = self.center_oneat)
-                                     if boxprediction is not None and len(boxprediction) > 0:
-                                            
-                                           
-                                                boxprediction[0]['real_time_event'] = inputtime
-                                                boxprediction[0]['xcenter'] = xcenter 
-                                                boxprediction[0]['ycenter'] = ycenter
-                                                boxprediction[0]['xstart'] = xcenter  - int(self.imagex/2) * self.downsamplefactor
-                                                boxprediction[0]['ystart'] = ycenter  - int(self.imagey/2) * self.downsamplefactor  
-                                                eventboxes = eventboxes + boxprediction
-                                           
+                if  str(int(inputtime)) in self.marker_tree:                     
+                        tree, location = self.marker_tree[str(int(inputtime))]
+                        for i in range(len(location)):
+                            
+                            crop_xminus = location[i][1]  - int(self.imagex/2) * self.downsamplefactor 
+                            crop_xplus = location[i][1]  + int(self.imagex/2) * self.downsamplefactor 
+
+                            crop_yminus = location[i][0]  - int(self.imagey/2) * self.downsamplefactor 
+                            crop_yplus = location[i][0]   + int(self.imagey/2) * self.downsamplefactor 
+                            region =(slice(0,smallimage.shape[0]),slice(int(crop_yminus), int(crop_yplus)),
+                                slice(int(crop_xminus), int(crop_xplus)))
+                            
+                            crop_image = smallimage[region] 
+                            
+                            if crop_image.shape[0] >= self.imaget and  crop_image.shape[1] >= self.imagey * self.downsamplefactor and crop_image.shape[2] >= self.imagex * self.downsamplefactor:                                                
+                                        #Now apply the prediction for counting real events
+                                    
+                                        crop_image = DownsampleData(crop_image, self.downsamplefactor)
+                                        ycenter = location[i][0]
+                                        xcenter = location[i][1]
+                                        
+                                        predictions, allx, ally = self.predict_main(crop_image)
+                                        sum_time_prediction = predictions[0]
+                                        if sum_time_prediction is not None:
+                                            #For each tile the prediction vector has shape N H W Categories + Training Vector labels
+                                            time_prediction =  sum_time_prediction[0]
+                                            boxprediction = yoloprediction(0, 0 , time_prediction, self.stride,
+                                                                inputtime, self.config,
+                                                                self.key_categories, self.key_cord, self.nboxes, 'detection',
+                                                                'dynamic', center_oneat = self.center_oneat)
+                                            if boxprediction is not None and len(boxprediction) > 0 and xcenter - self.pad_width[1]//2 > 0 and ycenter - self.pad_width[0]//2 > 0 and xcenter  < self.image.shape[2] - self.pad_width[1]//2 and ycenter  < self.image.shape[1] - self.pad_width[0]//2:
+                                                    
+                                                        
+                                                        boxprediction[0]['real_time_event'] = inputtime
+                                                        boxprediction[0]['xcenter'] = xcenter - self.pad_width[1]//2
+                                                        boxprediction[0]['ycenter'] = ycenter - self.pad_width[0]//2
+                                                        boxprediction[0]['xstart'] = boxprediction[0]['xcenter']   - int(self.imagex/2) * self.downsamplefactor
+                                                        boxprediction[0]['ystart'] = boxprediction[0]['ycenter']   - int(self.imagey/2) * self.downsamplefactor  
+                                                        eventboxes = eventboxes + boxprediction
+                                                
                                            
                 for (event_name,event_label) in self.key_categories.items(): 
                                            
@@ -612,7 +604,7 @@ class NEATDynamic(object):
             if event_label > 0:
                #best_sorted_event_box = self.classedboxes[event_name][0]
                if self.remove_markers is not None:
-                   best_sorted_event_box = gold_nms(self.heatmap,self.eventmarkers, self.classedboxes, event_name, 1, self.iou_threshold, self.event_threshold, self.imagex, self.imagey,generate_map = self.generate_maps, nms_function = self.nms_function )
+                   best_sorted_event_box = dynamic_nms(self.heatmap,self.classedboxes, event_name,  1, self.iou_threshold, self.event_threshold, self.imagex, self.imagey, self.fidelity,generate_map = self.generate_maps, nms_function = self.nms_function )
 
                if self.remove_markers is None:
                    best_sorted_event_box = dynamic_nms(self.heatmap,self.classedboxes, event_name,  self.downsamplefactor, self.iou_threshold, self.event_threshold, self.imagex, self.imagey, self.fidelity,generate_map = self.generate_maps, nms_function = self.nms_function )
@@ -625,77 +617,14 @@ class NEATDynamic(object):
 
     def to_csv(self):
          if self.remove_markers is not None:
-            save_dynamic_csv(self.imagename, self.key_categories, self.iou_classedboxes, self.savedir, 1, self.ndim, z = self.z)        
+            save_dynamic_csv(self.imagename, self.key_categories, self.iou_classedboxes, self.savedir, 1,  z = self.z)        
          if self.remove_markers is None:
-            save_dynamic_csv(self.imagename, self.key_categories, self.iou_classedboxes, self.savedir, self.downsamplefactor, self.ndim, z = self.z)          
+            save_dynamic_csv(self.imagename, self.key_categories, self.iou_classedboxes, self.savedir, self.downsamplefactor,  z = self.z)          
   
 
     
 
-    def showNapari(self, imagedir, savedir, yolo_v2=False):
-
-        Raw_path = os.path.join(imagedir, '*tif')
-        X = glob.glob(Raw_path)
-        self.savedir = savedir
-        Imageids = []
-        self.viewer = napari.Viewer()
-        napari.run()
-        for imagename in X:
-            Imageids.append(imagename)
-
-        eventidbox = QComboBox()
-        eventidbox.addItem(EventBoxname)
-        for (event_name, event_label) in self.key_categories.items():
-            eventidbox.addItem(event_name)
-
-        imageidbox = QComboBox()
-        imageidbox.addItem(Boxname)
-        detectionsavebutton = QPushButton(' Save detection Movie')
-
-        for i in range(0, len(Imageids)):
-            imageidbox.addItem(str(Imageids[i]))
-
-        figure = plt.figure(figsize=(4, 4))
-        multiplot_widget = FigureCanvas(figure)
-        ax = multiplot_widget.figure.subplots(1, 1)
-        width = 400
-        dock_widget = self.viewer.window.add_dock_widget(
-            multiplot_widget, name="EventStats", area='right')
-        multiplot_widget.figure.tight_layout()
-        self.viewer.window._qt_window.resizeDocks([dock_widget], [width], Qt.Horizontal)
-        eventidbox.currentIndexChanged.connect(lambda eventid=eventidbox: EventViewer(
-            self.viewer,
-            imread(imageidbox.currentText()),
-            eventidbox.currentText(),
-            self.key_categories,
-            os.path.basename(os.path.splitext(imageidbox.currentText())[0]),
-            savedir,
-            multiplot_widget,
-            ax,
-            figure,
-            yolo_v2,
-
-        )
-                                               )
-
-        imageidbox.currentIndexChanged.connect(
-            lambda trackid=imageidbox: EventViewer(
-                self.viewer,
-                imread(imageidbox.currentText()),
-                eventidbox.currentText(),
-                self.key_categories,
-                os.path.basename(os.path.splitext(imageidbox.currentText())[0]),
-                savedir,
-                multiplot_widget,
-                ax,
-                figure,
-                yolo_v2,
-
-            )
-        )
-
-        self.viewer.window.add_dock_widget(eventidbox, name="Event", area='left')
-        self.viewer.window.add_dock_widget(imageidbox, name="Image", area='left')
+   
 
     def overlaptiles(self, sliceregion):
 
@@ -706,7 +635,7 @@ class NEATDynamic(object):
             patchx = sliceregion.shape[2] // self.n_tiles[0]
             patchy = sliceregion.shape[1] // self.n_tiles[1]
             patchshape = (patchy, patchx)
-            smallpatch, smallrowout, smallcolumn = chunk_list(sliceregion, patchshape, self.stride, [0, 0])
+            smallpatch, smallrowout, smallcolumn = chunk_list(sliceregion, patchshape, [0, 0])
             patch.append(smallpatch)
             rowout.append(smallrowout)
             column.append(smallcolumn)
@@ -754,7 +683,7 @@ class NEATDynamic(object):
                     rowout = []
                     column = []
                     for pair in pairs:
-                        smallpatch, smallrowout, smallcolumn = chunk_list(sliceregion, patchshape, self.stride, pair)
+                        smallpatch, smallrowout, smallcolumn = chunk_list(sliceregion, patchshape, pair)
                         if smallpatch.shape[1] >= self.imagey and smallpatch.shape[2] >= self.imagex:
                             patch.append(smallpatch)
                             rowout.append(smallrowout)
@@ -768,7 +697,7 @@ class NEATDynamic(object):
                 patchx = sliceregion.shape[2] // self.n_tiles[0]
                 patchy = sliceregion.shape[1] // self.n_tiles[1]
                 patchshape = (patchy, patchx)
-                smallpatch, smallrowout, smallcolumn = chunk_list(sliceregion, patchshape, self.stride, [0, 0])
+                smallpatch, smallrowout, smallcolumn = chunk_list(sliceregion, patchshape,[0, 0])
                 patch.append(smallpatch)
                 rowout.append(smallrowout)
                 column.append(smallcolumn)
@@ -817,29 +746,18 @@ class NEATDynamic(object):
 
         return prediction_vector
 
-    def second_make_patches(self, sliceregion):
-
-        predict_im = np.expand_dims(sliceregion, 0)
-
-        prediction_vector = self.model.predict(np.expand_dims(predict_im, -1), verbose=0)
-
-        return prediction_vector
-
-    def make_batch_patches(self, sliceregion):
-
-        prediction_vector = self.model.predict(np.expand_dims(sliceregion, -1), verbose=0)
-        return prediction_vector
+    
 
 
-def CreateVolume(patch, imaget, timepoint):
-    starttime = timepoint
-    endtime = timepoint + imaget
+def CreateVolume(patch, size_tminus, size_tplus, timepoint):
+    starttime = timepoint - int(size_tminus)
+    endtime = timepoint + int(size_tplus) + 1
     smallimg = patch[starttime:endtime, :]
 
     return smallimg
 
 
-def chunk_list(image, patchshape, stride, pair):
+def chunk_list(image, patchshape, pair):
     rowstart = pair[0]
     colstart = pair[1]
 
@@ -862,91 +780,3 @@ def chunk_list(image, patchshape, stride, pair):
     return patch, rowstart, colstart
 
 
-class EventViewer(object):
-
-    def __init__(self, viewer, image, event_name, key_categories, imagename, savedir, canvas, ax, figure, yolo_v2):
-
-        self.viewer = viewer
-        self.image = image
-        self.event_name = event_name
-        self.imagename = imagename
-        self.canvas = canvas
-        self.key_categories = key_categories
-        self.savedir = savedir
-        self.ax = ax
-        self.yolo_v2 = yolo_v2
-        self.figure = figure
-        self.plot()
-
-    def plot(self):
-
-        self.ax.cla()
-
-        for (event_name, event_label) in self.key_categories.items():
-            if event_label > 0 and self.event_name == event_name:
-                csvname = self.savedir + "/" + event_name + "Location" + (
-                        os.path.splitext(os.path.basename(self.imagename))[0] + '.csv')
-                event_locations, size_locations, angle_locations, line_locations, timelist, eventlist = self.event_counter(
-                    csvname)
-
-                for layer in list(self.viewer.layers):
-                    if event_name in layer.name or layer.name in event_name or event_name + 'angle' in layer.name or layer.name in event_name + 'angle':
-                        self.viewer.layers.remove(layer)
-                    if 'Image' in layer.name or layer.name in 'Image':
-                        self.viewer.layers.remove(layer)
-                self.viewer.add_image(self.image, name='Image')
-                self.viewer.add_points(np.asarray(event_locations), size=size_locations, name=event_name,
-                                       face_color=[0] * 4, edge_color="red", edge_width=1)
-                if self.yolo_v2:
-                    self.viewer.add_shapes(np.asarray(line_locations), name=event_name + 'angle', shape_type='line',
-                                           face_color=[0] * 4, edge_color="red", edge_width=1)
-                self.viewer.theme = 'light'
-                self.ax.plot(timelist, eventlist, '-r')
-                self.ax.set_title(event_name + "Events")
-                self.ax.set_xlabel("Time")
-                self.ax.set_ylabel("Counts")
-                self.figure.canvas.draw()
-                self.figure.canvas.flush_events()
-                plt.savefig(self.savedir + event_name + '.png')
-
-    def event_counter(self, csv_file):
-
-        time, y, x, score, size, confidence, angle = np.loadtxt(csv_file, delimiter=',', skiprows=1, unpack=True)
-
-        radius = 10
-        eventcounter = 0
-        eventlist = []
-        timelist = []
-        listtime = time.tolist()
-        listy = y.tolist()
-        listx = x.tolist()
-        listsize = size.tolist()
-        listangle = angle.tolist()
-
-        event_locations = []
-        size_locations = []
-        angle_locations = []
-        line_locations = []
-        for i in range(len(listtime)):
-            tcenter = int(listtime[i])
-            ycenter = listy[i]
-            xcenter = listx[i]
-            size = listsize[i]
-            angle = listangle[i]
-            eventcounter = listtime.count(tcenter)
-            timelist.append(tcenter)
-            eventlist.append(eventcounter)
-
-            event_locations.append([tcenter, ycenter, xcenter])
-            size_locations.append(size)
-
-            xstart = xcenter + radius * math.cos(angle)
-            xend = xcenter - radius * math.cos(angle)
-
-            ystart = ycenter + radius * math.sin(angle)
-            yend = ycenter - radius * math.sin(angle)
-            line_locations.append([[tcenter, ystart, xstart], [tcenter, yend, xend]])
-            angle_locations.append(angle)
-
-        return event_locations, size_locations, angle_locations, line_locations, timelist, eventlist
-
