@@ -8,35 +8,23 @@ Created on Sat May 23 15:13:01 2020
 
 from oneat.NEATUtils import plotters
 import numpy as np
-from oneat.NEATUtils import helpers
-from oneat.NEATUtils.helpers import load_json, yoloprediction, normalizeFloatZeroOne, \
+from oneat.NEATUtils import utils
+from oneat.NEATUtils.utils import load_json, yoloprediction, normalizeFloatZeroOne, \
  goodboxes, save_static_csv, DownsampleData
 from keras import callbacks
 import os
 from tqdm import tqdm
 from oneat.NEATModels import nets
 from oneat.NEATModels.nets import Concat
-from oneat.NEATModels.loss import static_yolo_loss, static_yolo_loss_segfree, class_yolo_loss
+from oneat.NEATModels.loss import static_yolo_loss, class_yolo_loss
 from keras import backend as K
 import tensorflow as tf
 # from IPython.display import clear_output
-from keras import optimizers
 from pathlib import Path
 from keras.models import load_model
-from tifffile import imread, imwrite
-import csv
-import napari
-#from napari.qt.threading import thread_worker
-import matplotlib.pyplot as plt
-#from matplotlib.backends.backend_qt5agg import \
-    #FigureCanvasQTAgg as FigureCanvas
-from matplotlib.figure import Figure
-#from qtpy.QtCore import Qt
-#from qtpy.QtWidgets import QComboBox, QPushButton, QSlider
-import glob
+from tensorflow.keras.utils import plot_model
+from tifffile import imread
 import h5py
-#import cv2
-import imageio
 
 Boxname = 'ImageIDBox'
 CellTypeBoxname = 'CellIDBox'
@@ -75,7 +63,7 @@ class NEATStatic(object):
     
     """
 
-    def __init__(self, staticconfig, model_dir, model_name, catconfig=None, cordconfig=None, class_only = False):
+    def __init__(self, staticconfig, model_dir, model_name, catconfig=None, cordconfig=None, class_only = False, train_lstm = False):
 
         self.staticconfig = staticconfig
         self.catconfig = catconfig
@@ -83,6 +71,7 @@ class NEATStatic(object):
         self.model_dir = model_dir
         self.model_name = model_name
         self.class_only = class_only
+        self.train_lstm = train_lstm
         if self.staticconfig != None:
             self.npz_directory = staticconfig.npz_directory
             self.npz_name = staticconfig.npz_name
@@ -109,7 +98,7 @@ class NEATStatic(object):
             self.gridx = staticconfig.gridx
             self.gridy = staticconfig.gridy
             self.yolo_v0 = staticconfig.yolo_v0
-           
+            self.stride = staticconfig.stride
 
         if self.staticconfig == None:
 
@@ -140,6 +129,7 @@ class NEATStatic(object):
             self.gridx = self.staticconfig['gridx']
             self.gridy = self.staticconfig['gridy']
             self.yolo_v0 = self.staticconfig['yolo_v0']
+            self.stride = self.staticconfig['stride']
         
             self.stage_number = self.staticconfig['stage_number']
             self.last_conv_factor = 2 ** (self.stage_number - 1)
@@ -153,10 +143,16 @@ class NEATStatic(object):
         self.Xoriginal = None
         self.Xoriginal_val = None
         if self.class_only == False:
-                if self.residual:
-                    self.model_keras = nets.resnet_v2
-                else:
-                    self.model_keras = nets.seqnet_v2
+
+                if self.train_lstm == False:     
+                    if self.residual:
+                        self.model_keras = nets.resnet_v2
+                    else:
+                        self.model_keras = nets.seqnet_v2
+
+                if self.train_lstm:
+
+                        self.model_keras = nets.resnet_lstm_v2        
 
                 if self.multievent == True:
                     self.last_activation = 'sigmoid'
@@ -171,7 +167,11 @@ class NEATStatic(object):
 
         if self.class_only:
                 
-                self.model_keras = nets.resnet_v2_class
+
+                if self.train_lstm == False:
+                   self.model_keras = nets.resnet_v2_class
+                if self.train_lstm:
+                    self.model_keras = nets.resnet_lstm_v2_class   
 
                 if self.multievent == True:
                     self.last_activation = 'sigmoid'
@@ -186,9 +186,9 @@ class NEATStatic(object):
 
     def loadData(self, sum_channels = False):
 
-        (X, Y), axes = helpers.load_full_training_data(self.npz_directory, self.npz_name, verbose=True)
+        (X, Y), axes = utils.load_full_training_data(self.npz_directory, self.npz_name, verbose=True)
 
-        (X_val, Y_val), axes = helpers.load_full_training_data(self.npz_directory, self.npz_val_name, verbose=True)
+        (X_val, Y_val), axes = utils.load_full_training_data(self.npz_directory, self.npz_val_name, verbose=True)
 
         self.Xoriginal = X
         self.Xoriginal_val = X_val
@@ -258,14 +258,15 @@ class NEATStatic(object):
         sgd = tf.keras.optimizers.Adam(learning_rate=self.learning_rate)
         self.Trainingmodel.compile(optimizer=sgd, loss=self.yololoss, metrics=['accuracy'])
         self.Trainingmodel.summary()
-
+        plot_model(self.Trainingmodel, to_file = self.model_dir + self.model_name +'.png', 
+        show_shapes = True, show_layer_names=True)
         # Keras callbacks
         lrate = callbacks.ReduceLROnPlateau(monitor='loss', factor=0.1, patience=4, verbose=1)
         hrate = callbacks.History()
         srate = callbacks.ModelCheckpoint(self.model_dir + self.model_name, monitor='loss', verbose=1,
                                           save_best_only=False, save_weights_only=False, mode='auto', period=1)
         prate = plotters.PlotStaticHistory(self.Trainingmodel, self.X_val, self.Y_val, self.key_categories,
-                                           self.key_cord, self.gridx, self.gridy, plot=self.show, nboxes=self.nboxes)
+                                           self.key_cord, self.gridx, self.gridy, plot=self.show, nboxes=self.nboxes, class_only = self.class_only)
 
         # Train the model and save as a h5 file
         self.Trainingmodel.fit(self.X, self.Y, batch_size=self.batch_size, epochs=self.epochs,
@@ -302,6 +303,7 @@ class NEATStatic(object):
         self.event_threshold = event_threshold
         self.originalimage = self.image
         self.image = DownsampleData(self.image, self.downsamplefactor)
+        
         self.normalize = normalize
         f = h5py.File(self.model_dir + self.model_name + '.h5', 'r+')
         data_p = f.attrs['training_config']
@@ -313,22 +315,14 @@ class NEATStatic(object):
 
         eventboxes = []
         classedboxes = {}
-        count = 0
-        savenameDynamic = self.savedir + "/" + (
-        os.path.splitext(os.path.basename(self.imagename))[0]) + '_ColoredDynamic'
-        savenameStatic = self.savedir + "/" + (
-            os.path.splitext(os.path.basename(self.imagename))[0]) + '_ColoredStatic'
+        if self.normalize:
+                    self.image = normalizeFloatZeroOne(self.image, 1, 99.8)
+       
         if RGB == False:
             for inputtime in tqdm(range(0, self.image.shape[0])):
-                if inputtime < self.image.shape[0]:
-                    if inputtime >= self.image.shape[0] - 1:
-                        imwrite((savenameDynamic + '.tif'), self.ColorimageDynamic)
-                        imwrite((savenameStatic + '.tif'), self.ColorimageStatic)
-
-                    count = count + 1
+                
                 smallimage = self.image[inputtime, :]
-                if self.normalize:
-                    smallimage = normalizeFloatZeroOne(smallimage, 1, 99.8)
+                
                 # Break image into tiles if neccessary
                 predictions, allx, ally = self.predict_main(smallimage)
                 
@@ -366,7 +360,6 @@ class NEATStatic(object):
                 self.to_csv()
                 eventboxes = []
                 classedboxes = {}
-                count = 0
 
         if RGB:
 
@@ -413,7 +406,6 @@ class NEATStatic(object):
             self.to_csv()
             eventboxes = []
             classedboxes = {}
-            count = 0
 
     def nms(self):
 
@@ -435,7 +427,7 @@ class NEATStatic(object):
     def to_csv(self):
 
         
-        save_static_csv(self.ColorimageStatic, self.ColorimageDynamic, self.imagename, self.key_categories, self.iou_classedboxes, self.savedir, self.downsamplefactor)
+        save_static_csv(self.imagename, self.key_categories, self.iou_classedboxes, self.savedir, self.downsamplefactor)
    
 
 
@@ -467,7 +459,7 @@ class NEATStatic(object):
                 jumpy = int(self.overlap_percent * patchy)
 
                 patchshape = (patchy, patchx)
-                rowstart = 0;
+                rowstart = 0
                 colstart = 0
                 pairs = []
                 # row is y, col is x
@@ -584,66 +576,3 @@ def chunk_list(image, patchshape, pair):
     return patch, rowstart, colstart
 
 
-class CellTypeViewer(object):
-
-    def __init__(self, viewer, image, celltype_name, key_categories, imagename, savedir, canvas, ax, figure):
-
-        self.viewer = viewer
-        self.image = image
-        self.celltype_name = celltype_name
-        self.imagename = imagename
-        self.canvas = canvas
-        self.key_categories = key_categories
-        self.savedir = savedir
-
-        self.plot()
-
-    def plot(self):
-
-        for (celltype_name, event_label) in self.key_categories.items():
-            if event_label > 0 and self.celltype_name == celltype_name:
-                csvname = self.savedir + "/" + celltype_name + "Location" + (
-                            os.path.splitext(os.path.basename(self.imagename))[0] + '.csv')
-                event_locations, size_locations, timelist, eventlist = self.event_counter(csvname)
-
-                for layer in list(self.viewer.layers):
-                    if celltype_name in layer.name or layer.name in celltype_name:
-                        self.viewer.layers.remove(layer)
-                    if 'Image' in layer.name or layer.name in 'Image':
-                        self.viewer.layers.remove(layer)
-                self.viewer.add_image(self.image, name='Image')
-                self.viewer.add_points(np.asarray(event_locations), size=size_locations, name=celltype_name,
-                                       face_color=[0] * 4, edge_color="red", edge_width=1)
-                self.viewer.theme = 'light'
-
-    def event_counter(self, csv_file):
-
-        time, y, x, score, size, confidence = np.loadtxt(csv_file, delimiter=',', skiprows=1, unpack=True)
-
-        eventcounter = 0
-        eventlist = []
-        timelist = []
-        listtime = time.tolist()
-        listy = y.tolist()
-        listx = x.tolist()
-        listsize = size.tolist()
-
-        event_locations = []
-        size_locations = []
-
-        for i in range(len(listtime)):
-            tcenter = listtime[i]
-            ycenter = listy[i]
-            xcenter = listx[i]
-            size = listsize[i]
-            eventcounter = listtime.count(tcenter)
-            timelist.append(tcenter)
-            eventlist.append(eventcounter)
-
-            event_locations.append([tcenter, ycenter, xcenter])
-            if size > 1:
-                size_locations.append(size)
-            else:
-                size_locations.append(2)
-
-        return event_locations, size_locations, timelist, eventlist
