@@ -2,7 +2,6 @@ from poplib import POP3_SSL_PORT
 import pandas as pd
 import numpy as np
 import os
-from tqdm import tqdm
 import napari
 from scipy import spatial
 from skimage import measure
@@ -10,14 +9,14 @@ from dask.array.image import imread as daskread
 from tifffile import imread,  imwrite
 from skimage import morphology
 import csv
-import matplotlib.pyplot as plt
-import cv2
+from scipy.ndimage import zoom
 class OneatVisualization:
 
-    def __init__(self, viewer: napari.Viewer,key_categories, 
+    def __init__(self, viewer: napari.Viewer,key_categories, csvdir,
      savedir, savename, ax, figure):
 
         self.viewer = viewer
+        self.csvdir = csvdir
         self.savedir = savedir
         self.savename = savename
         self.key_categories = key_categories
@@ -49,56 +48,39 @@ class OneatVisualization:
         self.originalimage = None
         
     # To prevent early detectin of events
-    def cluster_points(self, nms_space, nms_time):
+    def cluster_points(self, nms_space,  use_dask = False, heatmapsteps = 0):
 
      print('before',len(self.event_locations_size_dict))
+    
+
      for (k,v) in self.event_locations_dict.items():
          currenttime = k
          event_locations = v
        
-        
-         tree = spatial.cKDTree(event_locations)
-         for i in range(1, nms_time):
-                    backtime = currenttime - i
-                 
-                    if int(backtime) in self.event_locations_dict.keys():
-                     
-                      back_event_locations = self.event_locations_dict[int(backtime)]
-                      for location in back_event_locations:
-                        if (int(backtime), int(location[0]), int(location[1])) in self.event_locations_size_dict:   
-                            backsize,backscore = self.event_locations_size_dict[int(backtime), int(location[0]), int(location[1])]
-                            distance, nearest_location = tree.query(location)
-                            nearest_location = int(event_locations[nearest_location][0]), int(event_locations[nearest_location][1])
-                            
-                            if distance <= nms_space:
-                                if (int(currenttime), int(nearest_location[0]), int(nearest_location[1])) in self.event_locations_size_dict:
-                                    currentsize, currentscore = self.event_locations_size_dict[int(currenttime), int(nearest_location[0]), int(nearest_location[1])]
-                                    if currentsize > backsize:
-                                        self.event_locations_size_dict.pop(( int(backtime), int(location[0]), int(location[1])))
-                                    else:
-                                        self.event_locations_size_dict.pop(( int(currenttime), int(nearest_location[0]), int(nearest_location[1]) ))    
-                    forwardtime = currenttime + i
-                    if int(forwardtime) in self.event_locations_dict.keys():
-                      forward_event_locations = self.event_locations_dict[int(forwardtime)]
-                      for location in forward_event_locations:
-                        if (int(forwardtime), int(location[0]), int(location[1])) in self.event_locations_size_dict:   
-                                forwardsize, forwardscore = self.event_locations_size_dict[int(forwardtime), int(location[0]), int(location[1])]
-                                distance, nearest_location = tree.query(location)
-                                nearest_location = int(event_locations[nearest_location][0]), int(event_locations[nearest_location][1])
+         if len(event_locations) > 0:
+            tree = spatial.cKDTree(event_locations)
+            forwardtime = currenttime + 1
+            if int(forwardtime) in self.event_locations_dict.keys():
+                forward_event_locations = self.event_locations_dict[int(forwardtime)]
+                for location in forward_event_locations:
+                   if (int(forwardtime), int(location[0]), int(location[1])) in self.event_locations_size_dict:   
+                        forwardsize, forwardscore = self.event_locations_size_dict[int(forwardtime), int(location[0]), int(location[1])]
+                        distance, nearest_location = tree.query(location)
+                        nearest_location = int(event_locations[nearest_location][0]), int(event_locations[nearest_location][1])
 
-                                if distance <= nms_space:
-                                            if (int(currenttime), int(nearest_location[0]), int(nearest_location[1])) in self.event_locations_size_dict:
-                                                currentsize, currentscore = self.event_locations_size_dict[int(currenttime), int(nearest_location[0]), int(nearest_location[1])]
-                                                if  currentsize > forwardsize:
-                                                    self.event_locations_size_dict.pop((int(forwardtime), int(location[0]), int(location[1])))
+                        if distance <= nms_space:
+                                    if (int(currenttime), int(nearest_location[0]), int(nearest_location[1])) in self.event_locations_size_dict:
+                                        currentsize, currentscore = self.event_locations_size_dict[int(currenttime), int(nearest_location[0]), int(nearest_location[1])]
+                                        if  currentscore >= forwardscore:
+                                            self.event_locations_size_dict.pop((int(forwardtime), int(location[0]), int(location[1])))
+                                            
+                                        if currentscore < forwardscore:
+                                            self.event_locations_size_dict.pop((int(currenttime), int(nearest_location[0]), int(nearest_location[1])))   
                                                     
-                                                else:
-                                                    self.event_locations_size_dict.pop((int(currenttime), int(nearest_location[0]), int(nearest_location[1])))   
-                                                       
      print('after',len(self.event_locations_size_dict))
-     self.show_clean_csv()                        
+     self.show_clean_csv(use_dask, heatmapsteps)                        
 
-    def show_clean_csv(self):
+    def show_clean_csv(self,use_dask = False, heatmapsteps = 0):
                 self.cleaneventlist = []
                 self.cleantimelist = [] 
                 self.event_locations_clean.clear()              
@@ -147,7 +129,7 @@ class OneatVisualization:
                             writer.writerows(event_data)
                             event_data = []     
                 name_remove = ('Clean Detections','Clean Location Map')
-               
+                
                 point_properties = {'score' : scores, 'confidence' : confidences,
                 'size' : radiuses}    
               
@@ -157,6 +139,7 @@ class OneatVisualization:
                                             self.viewer.layers.remove(layer) 
                 self.viewer.add_points(self.event_locations_clean, properties=point_properties,  name = 'Clean Detections', face_color = [0]*4, edge_color = "green") 
                 
+                                    
                 
                 df = pd.DataFrame (self.event_locations_clean, columns = ['T', 'Y', 'X'])
                 T_pred = df[df.keys()[0]][0:]
@@ -177,7 +160,7 @@ class OneatVisualization:
                 
                
 
-    def show_plot(self, imagename, plot_event_name, event_count_plot, event_norm_count_plot, cell_count_plot, 
+    def show_plot(self,  plot_event_name, event_count_plot, event_norm_count_plot, cell_count_plot, 
       segimagedir = None, event_threshold = 0 ):
 
         timelist = []
@@ -203,9 +186,7 @@ class OneatVisualization:
 
                 if self.image is not None:    
                         currentT   = np.round(self.dataset["T"]).astype('int')
-                        currentZ = np.round(self.dataset["Z"]).astype('int')
                         currentsize = self.dataset["Score"]
-                        currentConf = self.dataset["Confidence"]   
                             
                         for i in range(0, self.image.shape[0]):
                             
@@ -219,8 +200,8 @@ class OneatVisualization:
                             if self.segimagedir is not None and self.seg_image is not None:
                                 
                                 all_cells = self.cell_count[i]
-                                celllist.append(all_cells)
-                                normeventlist.append(countT/all_cells)
+                                celllist.append(all_cells + 1)
+                                normeventlist.append(countT/(all_cells+1))
                         self.cleannormeventlist = []    
                         if len(self.cleaneventlist) > 0:    
                                 for k in range(len(self.cleaneventlist)):
@@ -291,18 +272,23 @@ class OneatVisualization:
                         self.seg_image = daskread(segimagedir + imagename + '.tif')[0]
                     else:
                         self.seg_image = imread(segimagedir + imagename + '.tif')    
-                    if len(self.seg_image.shape) == 4:
-                        self.seg_image =  MidSlices(self.seg_image, start_project_mid, end_project_mid, use_dask, axis = 1)
+
+                    if start_project_mid is not None or end_project_mid is not None:      
+                       if len(self.seg_image.shape) == 4:
+                          self.seg_image =  MidSlices(self.seg_image, start_project_mid, end_project_mid, use_dask, axis = 1)
+
 
                     
                     self.viewer.add_labels(self.seg_image.astype('uint16'), name = 'SegImage'+ imagename)
-                    
-                    self.props = measure.regionprops(self.seg_image)
+                   
                     
                         
             if len(self.image.shape) == 4:
                 self.originalimage = self.image
-                self.image =  MidSlices(self.image, start_project_mid, end_project_mid, use_dask, axis = 1)
+                if start_project_mid is not None or end_project_mid is not None:
+                   self.image =  MidSlices(self.image, start_project_mid, end_project_mid, use_dask, axis = 1)
+               
+                       
             else:
                 self.originalimage = self.image
             self.viewer.add_image(self.image, name= 'Image' + imagename )
@@ -315,7 +301,7 @@ class OneatVisualization:
         except:
              pass            
 
-    def show_csv(self, imagename, csv_event_name, segimagedir = None, event_threshold = 0, use_dask = False, heatmapsteps = 0, nms_space = 0, nms_time = 0):
+    def show_csv(self, imagename, csv_event_name, segimagedir = None, event_threshold = 0, use_dask = False, heatmapsteps = 0, nms_space = 0):
         
         csvname = None
         self.event_locations_size_dict.clear()
@@ -329,7 +315,7 @@ class OneatVisualization:
         for (event_name,event_label) in self.key_categories.items():
                     if event_label > 0 and csv_event_name == event_name:
                             self.event_label = event_label     
-                            csvname = self.savedir + "/" + event_name + "Location" + (os.path.splitext(os.path.basename(imagename))[0] + '.csv')
+                            csvname = self.csvdir + "/" + event_name + "Location" + (os.path.splitext(os.path.basename(imagename))[0] + '.csv')
         if csvname is not None:    
             
                 self.event_name = csv_event_name                         
@@ -361,14 +347,7 @@ class OneatVisualization:
                         zcenter = listz[i]
                         ycenter = listy[i]
                         xcenter = listx[i]
-                        if self.seg_image is None:
-                          size = listsize[i]
-                        else:
-                          label = self.seg_image[tcenter,int(ycenter),int(xcenter)]  
-                          for prop in self.props:
-                              if label == prop.label:
-                                 size =  prop.area
-                                 break   
+                        size = listsize[i]
                         score = listscore[i]
                         confidence = listconfidence[i]   
                         if score > event_threshold:
@@ -416,7 +395,7 @@ class OneatVisualization:
                                     
             
 
-                self.cluster_points(nms_space, nms_time)
+                self.cluster_points(nms_space,use_dask, heatmapsteps)
 
                                        
 
@@ -482,64 +461,6 @@ def MidSlices(Image, start_project_mid, end_project_mid, use_dask, axis = 1):
     return MaxProject       
 
 
-def TruePositives(csv_gt, csv_pred, thresholdscore = 1 -  1.0E-6,  thresholdspace = 10, thresholdtime = 2):
-    
-            
-            try:
-                
-                    tp = 0
-                  
-
-                    dataset_pred  = pd.read_csv(csv_pred, delimiter = ',')
-                    dataset_pred_index = dataset_pred.index
-
-                    T_pred = dataset_pred[dataset_pred.keys()[0]][0:]
-                    Y_pred = dataset_pred[dataset_pred.keys()[1]][0:]
-                    X_pred = dataset_pred[dataset_pred.keys()[2]][0:]
-                    Score_pred = dataset_pred[dataset_pred.keys()[3]][0:]
-                    
-                    
-                    listtime_pred = T_pred.tolist()
-                    listy_pred = Y_pred.tolist()
-                    listx_pred = X_pred.tolist()
-                    listscore_pred = Score_pred.tolist()
-                    location_pred = []
-                    for i in range(len(listtime_pred)):
-
-                        if listscore_pred[i] > thresholdscore:   
-                            location_pred.append([listtime_pred[i], listy_pred[i], listx_pred[i]])
-
-                    tree = spatial.cKDTree(location_pred)
-
-
-                    dataset_gt  = pd.read_csv(csv_gt, delimiter = ',')
-                    dataset_gt_index = dataset_gt.index
-
-                    T_gt = dataset_gt[dataset_gt.keys()[0]][0:]
-                    Y_gt = dataset_gt[dataset_gt.keys()[1]][0:]
-                    X_gt = dataset_gt[dataset_gt.keys()[2]][0:]
-
-                    listtime_gt = T_gt.tolist()
-                    listy_gt = Y_gt.tolist()
-                    listx_gt = X_gt.tolist()
-                    location_gt = []
-                    for i in range(len(listtime_gt)):
-                        
-                        index = [float(listtime_gt[i]), float(listy_gt[i]), float(listx_gt[i])]
-                        closestpoint = tree.query(index)
-                        spacedistance, timedistance = TimedDistance(index, location_pred[closestpoint[1]])
-                        
-                        if spacedistance < thresholdspace and timedistance < thresholdtime:
-                            tp  = tp + 1
-                    
-                    fn = FalseNegatives(csv_pred, csv_gt, thresholdscore = thresholdscore, thresholdspace = thresholdspace, thresholdtime = thresholdtime)
-                    fp = FalsePositives(csv_pred, csv_gt, thresholdscore = thresholdscore, thresholdspace = thresholdspace, thresholdtime = thresholdtime)
-                    return tp/len(listtime_gt) * 100, fn, fp
-                
-            except:
-                 
-                 return 'File not found'
-                 pass
 
  
 def DownsampleData(image, DownsampleFactor):
@@ -554,7 +475,7 @@ def DownsampleData(image, DownsampleFactor):
                         smallimage = np.zeros([image.shape[0],  height,width])
                         for i in range(0, image.shape[0]):
                               # resize image
-                              smallimage[i,:] = cv2.resize(image[i,:].astype('float32'), dim)         
+                              smallimage[i,:] = zoom(image[i,:].astype('float32'), dim)         
 
                         return smallimage
                     else:
@@ -624,139 +545,7 @@ def PatchGenerator(image,resultsdir,csv_gt,number_patches, patch_shape, size_tmi
                     writer.writerows(Data)
                     
                     
-def FalseNegatives(csv_pred, csv_gt, thresholdscore = 1 -  1.0E-6, thresholdspace = 10, thresholdtime = 2):
-    
-            
-            try:
-                
-                    
-                  
 
-                    dataset_pred  = pd.read_csv(csv_pred, delimiter = ',')
-                    dataset_pred_index = dataset_pred.index
-
-                    T_pred = dataset_pred[dataset_pred.keys()[0]][0:]
-                    Y_pred = dataset_pred[dataset_pred.keys()[1]][0:]
-                    X_pred = dataset_pred[dataset_pred.keys()[2]][0:]
-                    Score_pred = dataset_pred[dataset_pred.keys()[3]][0:]
-                    
-                    listtime_pred = T_pred.tolist()
-                    listy_pred = Y_pred.tolist()
-                    listx_pred = X_pred.tolist()
-                    listscore_pred = Score_pred.tolist()
-                    location_pred = []
-                    for i in range(len(listtime_pred)):
-                        
-                        
-                        if listscore_pred[i] > thresholdscore:
-                           location_pred.append([listtime_pred[i], listy_pred[i], listx_pred[i]])
-
-                    tree = spatial.cKDTree(location_pred)
-
-
-                    dataset_gt  = pd.read_csv(csv_gt, delimiter = ',')
-                    dataset_gt_index = dataset_gt.index
-
-                    T_gt = dataset_gt[dataset_gt.keys()[0]][0:]
-                    Y_gt = dataset_gt[dataset_gt.keys()[1]][0:]
-                    X_gt = dataset_gt[dataset_gt.keys()[2]][0:]
-
-                    listtime_gt = T_gt.tolist()
-                    listy_gt = Y_gt.tolist()
-                    listx_gt = X_gt.tolist()
-                    location_gt = []
-                    fn = len(listtime_gt)
-                    for i in range(len(listtime_gt)):
-                        
-                        index = [float(listtime_gt[i]), float(listy_gt[i]), float(listx_gt[i])]
-                        closestpoint = tree.query(index)
-                        spacedistance, timedistance = TimedDistance(index, location_pred[closestpoint[1]])
-
-                        if spacedistance < thresholdspace and timedistance < thresholdtime:
-                            fn  = fn - 1
-
-                            
-
-
-                    return fn/len(listtime_gt) * 100
-                
-            except:
-                 
-                 return 'File not found'
-                 pass             
-                
-def FalsePositives(csv_pred, csv_gt, thresholdscore = 1 -  1.0E-6, thresholdspace = 10, thresholdtime = 2):
-    
-            
-            try:
-                
-                    
-                  
-
-                    dataset_pred  = pd.read_csv(csv_pred, delimiter = ',')
-                    dataset_pred_index = dataset_pred.index
-
-                    T_pred = dataset_pred[dataset_pred.keys()[0]][0:]
-                    Y_pred = dataset_pred[dataset_pred.keys()[1]][0:]
-                    X_pred = dataset_pred[dataset_pred.keys()[2]][0:]
-                    Score_pred = dataset_pred[dataset_pred.keys()[3]][0:]
-                    
-                    listtime_pred = T_pred.tolist()
-                    listy_pred = Y_pred.tolist()
-                    listx_pred = X_pred.tolist()
-                    listscore_pred = Score_pred.tolist()
-                    location_pred = []
-                    
-
-
-                    dataset_gt  = pd.read_csv(csv_gt, delimiter = ',')
-                    dataset_gt_index = dataset_gt.index
-
-                    T_gt = dataset_gt[dataset_gt.keys()[0]][0:]
-                    Y_gt = dataset_gt[dataset_gt.keys()[1]][0:]
-                    X_gt = dataset_gt[dataset_gt.keys()[2]][0:]
-
-                    listtime_gt = T_gt.tolist()
-                    listy_gt = Y_gt.tolist()
-                    listx_gt = X_gt.tolist()
-                    location_gt = []
-                    fp = len(listtime_pred)
-                    
-                    for i in range(len(listtime_gt)):
-                        
-                     
-                           location_gt.append([listtime_gt[i], listy_gt[i], listx_gt[i]])
-
-                    tree = spatial.cKDTree(location_gt)
-                    for i in range(len(listtime_pred)):
-                        
-                        index = [float(listtime_pred[i]), float(listy_pred[i]), float(listx_pred[i])]
-                        closestpoint = tree.query(index)
-                        spacedistance, timedistance = TimedDistance(index, location_gt[closestpoint[1]])
-
-                        if spacedistance < thresholdspace and timedistance < thresholdtime:
-                            fp  = fp - 1
-
-                            
-
-
-                    return fp/len(listtime_pred) * 100
-                
-            except:
-                 
-                 return 'File not found'
-                 pass             
-                                
- 
-def TimedDistance(pointA, pointB):
-
-    
-     spacedistance = float(np.sqrt( (pointA[1] - pointB[1] ) * (pointA[1] - pointB[1] ) + (pointA[2] - pointB[2] ) * (pointA[2] - pointB[2] )  ))
-     
-     timedistance = float(np.abs(pointA[0] - pointB[0]))
-     
-     
-     return spacedistance, timedistance
                 
                 
 def GetMarkers(image):
@@ -771,11 +560,4 @@ def GetMarkers(image):
 
     markers = morphology.dilation(MarkerImage, morphology.disk(2))        
    
-    return markers    
-
-
-
-
-
-
-  
\ No newline at end of file
+    return markers  
\ No newline at end of file
